#coding=utf-8
# 操作实验
from physicsLab.experiment import *
# 电学实验
from physicsLab.electricity import *
# 模块化电路
from physicsLab.unionElements import *
# 天体物理实验
from physicsLab.astrophysics import *
# 电与磁实验
from physicsLab.electromagnetism import *
# 自定义异常类
from physicsLab.errors import *

'''
__all__ = [
    
]
'''